# Simulation

The purpose of the BDTsim project is the simulation of blockchain based data trading protocols.
Using BDTsim, you can simulate [different protocols](protocols.md) in [different environments](environments.md).
You can also [extend BDTsim](development.md) on your own to add even more protocols or environments, as you need.


## Simulation Results

Simulations within BDTsim are carried out to get the following characteristics of a blockchain based data trading protocol:

  * Seller Protocol Step Count
  * Seller Transaction Fees
  * Seller Risk
  * Buyer Protocol Step Count
  * Buyer Transaction Fees
  * Buyer Risk
